Finds maximum cardinality matchings using Kececioglu and Pecqueur [Paper](https://citeseerx.ist.psu.edu/document?repid=rep1&type=pdf&doi=8598bf1481ef09189db6e972a037eecd11822a03)

Kececioglu, John D., and A. Justin Pecqueur. "Computing Maximum-Cardinality Matchings in Sparse General Graphs." WAE. 1998.
